/* USMID @(#)uts/include/sys/errno.h	90.1	01/19/95 17:24:41 */

/*      COPYRIGHT CRAY RESEARCH, INC.
 *      UNPUBLISHED -- ALL RIGHTS RESERVED UNDER
 *      THE COPYRIGHT LAWS OF THE UNITED STATES.
 */

/*
 * Error codes
 *
 * NOTE:  Because error numbers are compiled into existing binary programs,
 * and because they are documented in several places, existing error numbers
 * should not be changed, and new error numbers should only be added if
 * they are really needed.
 *
 * Additions to this list should be reflected in the sys_errlist[] in
 * libc/gen/errlst.c and the error message catalog in libc/gen/sys.msg
 */
  
#define EPERM		1	/* Not super-user			*/
#define ENOENT		2	/* No such file or directory		*/
#define ESRCH		3	/* No such process			*/
#define EINTR		4	/* interrupted system call		*/
#define EIO		5	/* I/O error				*/
#define ENXIO		6	/* No such device or address		*/
#define E2BIG		7	/* Arg list too long			*/
#define ENOEXEC		8	/* Exec format error			*/
#define EBADF		9	/* Bad file number			*/
#define ECHILD		10	/* No child processes			*/
#define EAGAIN		11	/* Resource temporarily unavailable	*/
#define ENOMEM		12	/* Not enough space			*/
#define EACCES		13	/* Permission denied			*/
#define EFAULT		14	/* Bad address				*/
#define ENOTBLK		15	/* Block device required		*/
#define EBUSY		16	/* Mount device busy			*/
#define EEXIST		17	/* File exists				*/
#define EXDEV		18	/* Cross-device link			*/
#define ENODEV		19	/* No such device			*/
#define ENOTDIR		20	/* Not a directory			*/
#define EISDIR		21	/* Is a directory			*/
#define EINVAL		22	/* Invalid argument			*/
#define ENFILE		23	/* File table overflow			*/
#define EMFILE		24	/* Too many open files			*/
#define ENOTTY		25	/* Not a typewriter			*/
#define ETXTBSY		26	/* Text file busy			*/
#define EFBIG		27	/* File too large			*/
#define ENOSPC		28	/* No space left on device		*/
#define ESPIPE		29	/* Illegal seek				*/
#define EROFS		30	/* Read-only file system		*/
#define EMLINK		31	/* Too many links			*/
#define EPIPE		32	/* Broken pipe				*/
#define EDOM		33	/* Argument out of domain		*/
#define ERANGE		34	/* Result too large			*/
#define ENOMSG		35	/* No message of desired type		*/
#define EIDRM		36	/* Identifier removed			*/
#define ECHRNG		37	/* Channel number out of range		*/
#define EL2NSYNC	38	/* Level 2 not synchronized		*/
#define EL3HLT		39	/* Level 3 halted			*/
#define EL3RST		40	/* Level 3 reset			*/
#define ELNRNG		41	/* Link number out of range		*/
#define EUNATCH		42	/* Protocol driver not attached		*/
#define ENOCSI		43	/* No CSI structure available		*/
#define EL2HLT		44	/* Level 2 halted			*/
#define EDEADLK		45	/* Deadlock condition detected/avoided	*/
#define ENOLCK		46	/* No record locks available		*/
#define EINVFS		47	/* Not supported on this file system	*/

#define EFILECH		50	/* File changed				*/
#define EFILERM		51	/* File removed				*/
#define ERFLOCK		52	/* Recovery of file lock would block	*/
#define ENOSDS 		53	/* Recovery could not allocate SDS area	*/
#define EFILESH		54	/* File shared				*/
#define EMALFORMED	55	/* Malformed process collection		*/
#define EFOREIGNFS	56	/* Foreign file system			*/

#define EQUSR		60	/* User file/inode quota limit reached	*/
#define EQGRP		61	/* Group file/inode quota limit reached	*/
#define EQACT		62	/* Account file/inode quota limit reached */

#define EREMOTE		66	/* The object is remote			*/
#define EMULTIHOP	74	/* Multihop attempted			*/

#define ESHMA		75	/* Shared memory segments attached.  	*/

#define EPROCLIM	90	/* Process limit exceeded		*/
#define EMEMLIM		91	/* Memory limit exceeded		*/
#define EDISKLIM	92	/* Disk limit exceeded			*/
#define ETOOMANYU	93	/* Too many users			*/

#define ENAMETOOLONG	94	/* Filename too long 			*/
#define ENOSYS		95	/* Function not implemented 		*/
#define ENOTEMPTY	96	/* Directory not empty 			*/
#define ERENAMESELF	97	/* Rename to rename a link to itself	*/
#define ELOOP		98	/* Too many symbolic links		*/
#define EILSEQ		99	/* Illegal byte sequence		*/

#define ELASTSV		127	/* LAST System V error code		*/

/*
 * UNICOS specific error codes
 */

/* TCP/IP network, socket interface		128-199			*/

#define ETCP		128	/* FIRST TCP/IP error code		*/
#define EWOULDBLOCK	128	/* Operation would block (also used in	*/
				/* the pty driver)			*/
#define EINPROGRESS	129	/* Operation now in progress		*/
#define EALREADY	130	/* Operation already in progress	*/
#define ENOTSOCK	131	/* Socket operation on non-socket	*/
#define EDESTADDRREQ	132	/* Destination address required		*/
#define EMSGSIZE	133	/* Message too long			*/
#define EPROTOTYPE	134	/* Protocol wrong type for socket	*/
#define ENOPROTOOPT	135	/* Bad protocol option			*/
#define EPROTONOSUPPORT	136	/* Protocol not supported		*/
#define ESOCKTNOSUPPORT	137	/* Socket type not supported		*/
#define EOPNOTSUPP	138	/* Operation not supported on socket	*/
#define EPFNOSUPPORT	139	/* Protocol family not supported	*/
#define EAFNOSUPPORT	140	/* Address family not supported by	*/
				/* protocol family			*/
#define EADDRINUSE	141	/* Address already in use		*/
#define ENETUNREACH	142	/* Network is unreachable		*/
#define ENETRESET	143	/* Network dropped connection on reset	*/
#define ECONNABORTED	144	/* Software caused connection abort	*/
#define ECONNRESET	145	/* Connection reset by peer		*/
#define ENOBUFS		146	/* No buffer space available		*/
#define EISCONN		147	/* Socket is already connected		*/
#define ENOTCONN	148	/* Socket is not connected		*/
#define ESHUTDOWN	149	/* Can't send after socket shutdown	*/
#define ETOOMANYREFS	150	/* No free TP references available	*/
#define ETIMEDOUT	151	/* Connection timed out			*/
#define ECONNREFUSED	152	/* Connection refused			*/
#define EHOSTDOWN	153	/* Host is down				*/
#define EHOSTUNREACH	154	/* Host is unreachable			*/
#define EADDRNOTAVAIL	155	/* Can't assign requested address	*/
#define ENETDOWN	156	/* Network is down			*/
#define ELASTTCP	199	/* LAST TCP/IP error code		*/
  
/*	TPD-TSS driver interface		200-249			*/
  
#define EFIRSTTPD	200	/* FIRST TPD interface error code	*/
#define ETPDCNF		200	/* Tape open rejected due to config.	*/
#define ETPDOPN		201	/* Open reject due to already open	*/
#define ETPDABN		202	/* Tape I/O request with abnormal status*/
#define ETPDNRW 	203	/* No write ring on tape device		*/
#define ETPDBDF 	204	/* Bad data returned on tape read	*/
#define ETPDEOV 	205	/* Tape end of volume			*/
#define ETPDCLEAR 	206	/* Tape cleared by operator		*/
#define ETPDEOF		207	/* End of file (tape mark) read		*/
#define ETPDNODEM	208	/* Tape daemon not active		*/
#define ETPDBUFZ	209	/* Invalid user buffer size		*/
#define ETPDRWE		210	/* Read after write or write after read */
#define ETPDLIST	211	/* Error in list			*/
#define ETPDUERR	212	/* User error, only close allowed	*/
#define ETPDMBS		213	/* Maximum tape block size exceeded	*/
#define ETPDLBK		214	/* Large block tape error		*/
#define	ETPDACKERR	215	/* Acknowledge error before continueing */
#define	ETPDNOSYSBF	216	/* no more system buffer available      */
#define	ETPDSTOP	217	/* IOP is stopped			*/
#define	ETPDMAXDEVUP	218	/* Max tapes configured up will be exceeded */
#define	ETPD_PK_BADLEN	219	/* request packet larger than EPAK_MAXLEN */
				/* or less than 3			*/
#define	ETPD_PK_NOT_ALLOWED 220	/* request is not allowed 		*/
#define	ETPD_PK_SEND	221	/* error returned from epackout 	*/
#define	ETPD_PK_TIMEDOUT 222	/* iop timedout				*/
#define	ETPD_PK_CHAN_UP 223	/* channel not configured down		*/
#define	ETPD_PK_CHAN_OPENED 224	/* channel already opened 		*/

#define	ETINVCTL	225	/* Invalid ioctl request		*/
#define	ETPD_BAD_REQT	226	/* Bad request issued to iop		*/
#define	ETPD_BLANK_TAPE	227	/* Blank tape				*/
#define	ETPD_NOT_OPER	228	/* Device is not operational		*/
#define	ETPD_NOT_READY	229	/* Device is not ready			*/
#define	ETPD_EOT	230	/* End of Tape detected			*/
#define	ETPD_DATA_ERROR	231	/* Unrecoverable data error		*/
#define	ETPD_MEDIA	232	/* Media error				*/
#define	ETPD_EOR	233	/* End of Recording detected		*/
#define	ETPD_LGPS	234	/* Logical Position not established	*/
#define	ETPD_EOM	235	/* End of Media detected		*/
#define	ETPD_SYSTEM	236	/* Tape driver error			*/
#define	ETPD_DEVICE	237	/* Device error				*/
#define	ETPD_FORMAT	238	/* Format error/format not supported	*/
#define	ETPD_FILETYPE	239	/* Invalid file type			*/
#define	ETPD_NO_CASSETTE 240	/* Cassette is not loaded 		*/
#define	ETPD_TAPE_ADDR	241	/* Invalid tape address specified	*/
#define	ETPD_DEVDOWN	242	/* Device must be configured up		*/
#define	ETPD_NOT_BOF	243	/* Must be at beginning of file		*/
#define	ETPD_TAPE_ERROR	244	/* Tape Error				*/
#define	ETPD_DEV_HUNG	245	/* Device is hung			*/
#define	ETPD_MAX_IOREQT	246	/* Exceeded i/o request size maximum 	*/
#define	ETPD_ODD_BYTES	247	/* Cannot issue odd byte i/o request	*/
#define	ETPD_BLKSIZ_DIFF 248	/* Blocks must be same size within file */
#define	ETPD_POSACC_ERR	249	/* Position cannot be accessed		*/
#define ELASTTPD	249	/* the LAST TPD error code		*/

/* The following is added for compatability with cray2 and pre 8.0 cray1 */

#define EFIRSTBMX	EFIRSTTPD
#define EBMXCNF		ETPDCNF
#define EBMXOPN		ETPDOPN
#define EBMXABN		ETPDABN
#define EBMXNRW 	ETPDNRW
#define EBMXBDF 	ETPDBDF
#define EBMXEOV 	ETPDEOV
#define EBMXCLEAR 	ETPDCLEAR
#define EBMXEOF		ETPDEOF
#define EBMXNODEM	ETPDNODEM
#define EBMXBUFZ	ETPDBUFZ
#define EBMXRWE		ETPDRWE
#define EBMXLIST	ETPDLIST
#define EBMXUERR	ETPDUERR
#define EBMXMBS		ETPDMBS
#define EBMXLBK		ETPDLBK
#define	EBMXACKERR	ETPDACKERR
#define	EBMXNOSYSBF	ETPDNOSYSBF
#define	EBMXSTOP	ETPDSTOP
#define	EBMXMAXDEVUP	ETPDMAXDEVUP
#define ELASTBMX	ELASTTPD

/*	Communications driver error codes	250-299			*/

#define EFIRSTCOM	250	/* FIRST communications driver error	*/
#define ELATE		250	/* I/O request timeout (CX/1 & CEA only)*/
#define ENSC		251	/* NSC HYPERchannel write error (CRAY-2)*/
#define ELASTCOM	299	/* LAST comnunications driver error	*/

/*	Security violation error codes		300-349			*/
 
#define ESYSLV		300	/* Security level violation		*/
#define EREADV		301	/* Security read violation		*/
#define EWRITV		302	/* Security write violation		*/
#define EEXECV		303	/* Security execute violation		*/
#define ECOMPV		304	/* Security compartment violation	*/
#define EMANDV		305	/* Security mandatory access violation	*/
#define EOWNV		306	/* Security owner violation		*/
#define ELEVELV		307	/* Security level range violation	*/
#define ESECADM		308	/* Not security administrator		*/
#define EFLNEQ		309	/* Security mount violation		*/
#define ENOTEQ		310	/* Security buffer violation		*/
#define EPERMIT		311	/* Security permission violation	*/
#define EACLV		312	/* Access list violation		*/
#define ENOACL		313	/* No acl list found			*/
#define ESLBUSY		314	/* Security log in use			*/
#define ESLNXIO		315	/* Security log mode violation		*/
#define ESLFAULT	316	/* Security log read violation		*/
#define ESLNOLOG	317	/* Security log configured SLGOFF	*/
#define EINTCLSV	318	/* Security class violation		*/
#define EINTCATV	319	/* Security category violation		*/
#define ENONAL		320	/* No network authorization list (nal)	*/
#define EMNTCMP		321	/* Security mount compartment violation	*/
#define EFIFOV		322	/* Security FIFO violation		*/
#define EAPPNDV		323	/* Security append violation		*/
#define ETFMCATV	324	/* Security multi-category violation	*/
#define ECOVERT		325	/* Covert channel condition		*/
#define ERCLSFY		326	/* Security label reclassify violation	*/
#define EPRLABEL	327	/* Security label printing disabled	*/
#define ENONSECURE	328	/* Security is not enabled		*/
#define	ESECFLGV	329	/* Security flag violation		*/
#define EHOSTNAL	330	/* Host not authorized in NAL */
#define ESLVLNAL	331	/* Security level outside host's range  */
#define ESCMPNAL	332	/* Compartments outside host's range    */
#define EMODENAL	333	/* Illegal transmission for host (NAL)  */
#define ESLVLNIF	334	/* Security level outside network I/F   */
#define ESCMPNIF	335	/* Compartments	outside of network I/F  */
#define ESOCKLVL	336	/* Security level change of SLS tried   */
#define ESOCKCMP	337	/* Compartment change of SLS attempted  */
#define	ENFSAUTH	338	/* Invalid NFS authentication credential */
#define ESLVLNRT	339	/* Security level violation network route */
#define ESCMPNRT	340	/* Compartments	violation for network route */
#define EBADIPSO	341	/* Bad IP security option */
#define ENOIPSO		342	/* IP security option missing */
#define ESLVLMAP	343	/* Security level mapping error */
#define ESCMPMAP	344	/* Compartment mapping error */
#define EAUTHFLG	345	/* Authority flag violation */
#define EIPSOMAP	346	/* No map for security option */
#define ELASTSEC	349	/* LAST security error code		*/

/*	Data migration facility error codes	350-370			*/

#define EFIRSTDM	350	/* FIRST data migration error code	*/
#define EDMRNOLF	350	/* Not offline file; dmofrq system call	*/
#define EDMRBPAR	351	/* Invalid option; dmofrq system call	*/
#define EDMRWFT		352	/* Incorrect file type; dmofrq call	*/
#define EDMRNSD		353	/* Device doesn't match; dmofrq call	*/
#define EMASS		354	/* FileServ error: see ETAC logs for details */
#define EDMOFF		355	/* Data management system is off	*/
#define EOFFLIN		357	/* File offline, no automatic retrieval	*/
#define EOFLNDD		358	/* Request failed, daemon not available	*/
#define EOFLNNR		360	/* File offline, currently not retrievable */
#define EOFLRIN		361	/* File offline, retrieval interrupted	*/
#define EOFSPACE	362	/* File offline, not enough space to retrieve it */
#define EOFQUOTA	363	/* File offline, retrieval would exceed disk space quota */
#define EDMTRSTD	365	/* Function reserved for trusted subject only */
#define EDMOFRQ		367	/* Invalid or inconsistent dmofrq call	*/
#define EDMNBLK         368     /* Non-blocking recall; data recall from offline media is pending */
#define ELASTDM		370	/* LAST data migration error code	*/

/*	NFS/RPC and ID mapping error codes	371-399			*/

#define ENOIDMAP	371	/* Named ID map not found		*/
#define EMAPINUSE	372	/* Named ID map is in use (reference count nonzero) */
#define EMAPTYPE	373	/* Unknown ID map type			*/
#define EDUPMAPNAME	374	/* Duplicate ID map name		*/
#define EGIDMAPSIZE	375	/* Bad group ID map size		*/
#define EBADDOMAIN	376	/* ID mapping domain address doesn't make sense */
#define ENODOMAIN	377	/* ID mapping domain not found		*/
#define EBADADDR	378	/* ID mappng domain overlap error	*/
#define ENOUMAPENTRY	379	/* User ID map entry not found		*/
#define EREMOTEUID	380	/* Remote hash not found for user ID map entry, ID mapping disabled */
#define EUIDTYPE	381	/* Unknown user ID map entry type	*/
#define EDUPUMAPENTRY	382	/* Duplicate user ID map entry		*/
#define ESAMEIDMAP	383	/* This ID mapping domain is uneccessary*/
#define EMAPTHRUIDMAP	384	/* A Special ID map is already defined	*/
#define EMAPTHRUUID	385	/* Special ID map entry (luid != ruid).	*/
#define ENOKRBADDR	386	/* No Kerberos validated address found  */
#define EDUPKRBADDR	387	/* Dup Kerberos validated address found */
#define EKRBADDRINUSE	388	/* Kerberos address ref count nonzero	*/
#define ERPCCLNTBADV	391	/* Kerberos client rec'v bad verifier 	*/
#define ERPCREJVER	392	/* Server rejected client verfier	*/
#define EIDMADDR	393	/* Address not in ID mapping domains	*/
#define ESTALE		394	/* Stale NFS file handle		*/
#define ERPCCDRES	395	/* Can't decode RPC results		*/
#define ERPCCDARGS	396	/* Can't decode RPC arguments		*/
#define ERPCCANTSEND	397	/* Unable to send RPC request		*/
#define ERPCAUTH	398	/* RPC authentication error		*/
#define ERPC		399	/* Generic RPC error			*/
#define ELASTNFSERROR	399	/* LAST NFS/RPC error			*/


/*	IPI3/TPD packet interface driver error codes	400 - 449	*/


#define	EPKI_FIRST		400	/* First IPI-3 error code	    */
#define EPKI_NO_PACKETS		400	/* No packets available		    */
#define EPKI_PACKET_LOST	401	/* Packets lost - queue full 	    */
#define	EPKI_TRUNCATED		402	/* Packet truncated - size 	    */
					/*   is greater than maximum 	    */
#define EPKI_TOO_LARGE		403	/* Size of packet is larger than    */
					/*   in ipi3_ctl argument	    */
#define EPKI_ASYNCH_LIM		404	/* Too many async packets queued    */
#define EPKI_INVAL_CODE		405	/* Invalid request code sent	    */
#define	EPKI_NOT_ENABLED	406	/* packet interface not enabled	    */
#define	EPKI_REQ_LIM		407	/* Request limit exceeded	    */
#define	EPKI_BAD_RESYNC		408	/* Invalid resynchronization code   */
#define	EPKI_NO_START		409	/* IOS driver hasn't been started   */
#define	EPKI_CF_TYPE		410	/* Invalid configuration type	    */
#define	EPKI_PARM_ERR		411	/* Invalid configuration defini-    */
					/*   tion parameter		    */
#define	EPKI_DEV_LIM		412	/* Exceeded device limits	    */
#define	EPKI_IOS_ERR		413	/* IOS error on ipi-3 request	    */
#define	EPKI_REQT_TYPE		414	/* Request invalid for device type  */
#define	EPKI_IOCTL_REQT		415	/* Ioctl request is invalid for	    */
					/*   the device			    */
#define	EPKI_IOP_SEND		416	/* Error sending packet to an IOP   */
#define	EPKI_ACTIVE_IOP		417	/* Request error because IOP active */
#define	EPKI_DEVS_ACTIVE	418	/* Devices are active for the IOP   */
#define	EPKI_NOT_CONF		419	/* IPI-3 is not configured	    */
#define	EPKI_SYS_ERROR		420	/* Software error		    */
#define	EPKI_NO_DEVICE		421	/* Device requested not found	    */
#define	EPKI_PROC_LIM		422	/* Exceeded max number of processes */
					/*   allowed to open an IOP	    */
#define	EPKI_ALREADY_ENBL	423	/* Packets already enabled	    */
#define	EPKI_DEV_CLEAR		424	/* Device has been cleared	    */
#define	EPKI_CHAN_DOWN		425	/* Channel(s) to device are down    */
#define	EPKI_HALTIO_ERR		426	/* Halt i/o request failed	    */
#define	EPKI_SELRST_ERR		427	/* Selective reset request failed   */
#define	EPKI_SETATTR_ERR	428	/* Set attribute request failed	    */
#define	EPKI_RESPBUF_LOST	429	/* Packet copied into the response  */
					/*   buffer lost		    */
#define	EPKI_CMDLIST_LIM	430	/* Exceeded the command list limit  */
#define	EPKI_DRIVER_DOWN	431	/* Packet driver is down	    */
#define	EPKI_PEND_SHUTDOWN	432	/* Shutdown of packet driver is     */
					/*   pending			    */
#define	EPKI_DRIVER_UP		433	/* The packet driver is up	    */
#define	EPKI_PEND_STARTUP	434	/* Packet startup is pending	    */
#define	EPKI_DRIVER_ACTIVE	435	/* Packet driver is active	    */
#define	EPKI_STOP_DRIVER	436	/* Error on stop driver request	    */
#define	EPKI_IOP_NOT_CONF	437	/* IOP is not configured	    */
#define	EPKI_IOP_SHUTDOWN	438	/* IOP was shutdown		    */
#define	EPKI_ALREADY_CONF	439	/* IOP/Device is already configured */
#define EPKI_LAST		450	/* Last IPI-3 error code	    */



/*	File System (SFS) error codes		500-549			*/

#define	EFSEFIRST	500	/* FIRST file system error		*/
#define	EFSEMANA	500	/* Fast lock not available		*/
#define	EFSNOGROW	501	/* File has allocation restrictions	*/
#define	EFSNOTEXCL	502	/* File is not exclusive                */
#define	EFSEXCLWR	503	/* File is write protected              */
#define	EFSESDOWN	504	/* External semaphore device unavailable*/
#define	ENOTWELLFORMED	540	/* I/O request not well formed		*/
#define	EFSBAD		546	/* File system corrupted		*/
#define	EDBAD		547	/* Directory corrupted			*/
#define	EIBAD		549	/* File inode corrupted			*/
#define	EFSELAST	549	/* LAST file system error		*/

/*	MPP support error codes		600-609				*/
#define EMPPPEJLIM	600	/* MPP JOB PE limit exceeded		*/
#define EMPPBARJLIM	601	/* MPP JOB Barrier limit exceeded	*/
#define EMPPTIMJLIM	602	/* MPP JOB Time limit exceeded		*/
#define EMPPTIMPLIM	603	/* MPP PROC Time limit exceeded		*/
#define EMPPNOCHECK	604	/* checkpoint failed MPP resources held */

/*	TPD driver interface		610-809				*/

#define	ETPD_BOT	610	/* Positioned at the Beginning of Tape  */
#define	ETPD_DEV_RESET	611	/* Device was reset			*/
#define	ETPD_IOPERR	612	/* Problem with the IOP			*/
#define	ETPD_DEVBUSY	613	/* Device is busy			*/
#define	ETPD_IPCONN	614	/* IPI connection error			*/
#define	ETPD_SHPI	615	/* HIPPI controller error		*/
#define	ETPD_HPCONN	616	/* HIPPI connection error		*/
#define	ETPD_HPTRNS	617	/* HIPPI transmission error		*/
#define	ETPD_HPDATA	618	/* HIPPI data error			*/
#define	ETPD_HPREQ	619	/* HIPPI request error			*/
#define	ETPD_NO_UIO	620	/* no user I/O 			*/
#define	ETPD_DEMERR	621	/* Tape daemon detected an error	*/
#define	ETPD_NO_USER	622	/* The seesion id not know to the tape 
				   daemon */
#define	ETPD_NOMEM	623	/* The tape demon can't allocate memory	*/
#define	ETPD_CPR_GET	624	/* The tape daemon can't get tape 
				   chkpnt/restart record		*/
#define	ETPD_USER_EXIST 625	/* Session id already a tape user in the
				   tape daemon */
#define	ETPD_MAX_USER	626	/* Maximum number of tape user reached	*/
#define	ETPD_REQ_PIPE	627	/* User has a user request pipe		*/
#define	ETPD_INVALID_DGN 628	/* Invalid device group name 		*/
#define	ETPD_RS_MOUNT	629	/* Can't set restart mount status	*/
#define	ETPD_RESTART_CHILD 630	/* Can't create restart child		*/
#define	ETPD_PATHNAME	631	/* Can't create pathname 		*/
#define	ETPD_NOTCHAR	632	/* Pathname of tape file exists and is 
				   not a char special file	*/
#define	ETPD_EXIST	633	/* Pathname already used in tape daemon */
#define	ETPD_DEADLOCK	634	/* Allocation leads to a deadlock	*/
#define	ETPD_VOL_IN_USE 635	/* The volume requested is in use	*/
#define	ETPD_CHKRES_RCD 636	/* Can't find tape chkpnt record	*/ 
#define	ETPD_NO_BUFLIST 637	/* Can't find system buffer list	*/
#define	ETPD_NOFILE	638	/* Can't find filename			*/
#define	ETPD_CHKDEV	639	/* Can't find checkpointed device	*/
#define	ETPD_SET_OWNER	640	/* Can't set owner ID			*/
#define	ETPD_CHANGED	641	/* The system (Kernel/Daemon) changed	*/
#define	ETPD_LOST_POSITION 642	/* Position of tape is lost 		*/
#define	ETPD_CHKPNT_PROC 643	/* Can't checkpoint a tape process 	*/
#define	ETPD_SET_TPDTAB	644	/* Can't set tpdtab in kernel 		*/
#define	ETPD_BAD_DGN	645	/* Bad device group name		*/
#define	ETPD_RS_RESTART	646	/* Can't set restart flag in driver	*/
#define	ETPD_RESIO	647	/* request and restart don't match 	*/
#define	ETPD_NODEV	648	/* No device found in restart file	*/
#define	ENOPATHNAME	649	/* Pathname not found in restart file	*/
#define	ETPD_TIMEDOUT	650	/* Timed out 				*/

/*	Fortran library error codes		1000-1999		*/
/*	(reserved for Fortran library - see <liberrno.h>)		*/

#define EFLEFIRST	1000	/* FIRST Fortran library error		*/
#define EFLELAST	1999	/* LAST Fortran library error		*/

/*	ffio (FDC) library error codes		5000-5999		*/
/*	(reserved for libc/fdcio library - see <foreign.h>)		*/



